Package: sctk / 2.4.10-20151007-1312Z+dfsg2-3

1003_fix_mispellings.patch Patch series | download
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
Description: fix mispellings
 This patch fixes mispellings in binary files reported by lintian.
Author: Giulio Paci <giuliopaci@gmail.com>
Forwarded: yes
--- a/doc/asclite.pod
+++ b/doc/asclite.pod
@@ -111,7 +111,7 @@
 
 =item B<-memory-compression <block_KB>>
 
-Set the memory compression with compressed <block_KB> KB block (default: off / recommanded: 64).
+Set the memory compression with compressed <block_KB> KB block (default: off / recommended: 64).
 
 =item B<-force-memory-compression>
 
--- a/src/asclite/core/main.cpp
+++ b/src/asclite/core/main.cpp
@@ -78,7 +78,7 @@
     cout << "    -only-SG <segment_group_ID>" << endl;
     cout << "                  Only score the segment group specified (default: disable, scoring all Segment Groups)." << endl;
 	cout << "    -memory-compression <block_KB>" << endl;
-    cout << "                  Set the memory compression with compressed <block_KB> KB block (default: off / recommanded: 256)." << endl;
+    cout << "                  Set the memory compression with compressed <block_KB> KB block (default: off / recommended: 256)." << endl;
 	cout << "    -force-memory-compression" << endl;
     cout << "                  Force the memory compression." << endl;
 	cout << "    -memory-limit <max_GB>" << endl;
@@ -700,7 +700,7 @@
 			else
 			{
 				arg_ok = false;
-				cerr << "[  ERROR  ] Ouput dir missing!" << endl;
+				cerr << "[  ERROR  ] Output dir missing!" << endl;
 			}
 		}
 		else
--- a/src/asclite/core/speechset.cpp
+++ b/src/asclite/core/speechset.cpp
@@ -126,7 +126,7 @@
     }
     else
     {
-        LOG_WARN(logger, "The status of the SpeechSet dont exist (must be 'ref' or 'hyp') and was: "+status);
+        LOG_WARN(logger, "The status of the SpeechSet don't exist (must be 'ref' or 'hyp') and was: "+status);
     }
 	
     UpdatePropertiesIfNeeded(true);
--- a/src/sclite/corresp.c
+++ b/src/sclite/corresp.c
@@ -312,7 +312,7 @@
   int *evals;
 
   if (npaths == 0 || npaths == 1) {
-    fprintf(stderr,"Error: these are paths are not compatable");
+    fprintf(stderr,"Error: these paths are not compatible");
     exit(1);
   }
 
@@ -336,12 +336,12 @@
 	;
       else {
 	if (w > paths[0]->num || wp > paths[p]->num){
-	  fprintf(stderr,"Error: these are paths are not compatable");
+	  fprintf(stderr,"Error: these paths are not compatible");
 	  exit(1);
 	}
 	if (TEXT_strcmp(((WORD *)(paths[0]->pset[w].a_ptr))->value,
 			((WORD *)(paths[p]->pset[wp].a_ptr))->value) != 0){
-	  fprintf(stderr,"Error: these are paths are not compatable");
+	  fprintf(stderr,"Error: these paths are not compatible");
 	  exit(1);	
 	}
 	if (paths[p]->pset[wp].eval == P_CORR)
--- a/src/acomp/acomp.pl
+++ b/src/acomp/acomp.pl
@@ -51,7 +51,7 @@
 		      "s",
 		      "i:s",
 		      "f");
-die "\n$usage\nError: Failed to parse argements" if (! $ret);
+die "\n$Usage\nError: Failed to parse arguments" if (! $ret);
 
 
 if (defined($opt_l)) {  $Lex = $opt_l; } else { die("$Usage\n\nError: Lexicon required via -l.\n"); }
@@ -64,8 +64,8 @@
 	if ($opt_i !~ /^(txt|ctm|stm)$/);
     $InFmt = $opt_i;
 }
-#### The main functions arguements:
-if ($#ARGV > 1) { print "\n$Usage\nToo many arguements\n\n"; exit 1; } 
+#### The main functions arguments:
+if ($#ARGV > 1) { print "\n$Usage\nToo many arguments\n\n"; exit 1; }
 if ($#ARGV == 0) { print "\n$Usage\nOutput Not Specified\n\n"; exit 1; } 
 if ($#ARGV == -1) { print "\n$Usage\nInput and Output Not Specified\n\n";
 		    exit 1; }